yeelight package
================

This is the autogenerated API documentation. Use it as a reference to the public
API of the project.


yeelight module
---------------

.. autofunction:: yeelight.discover_bulbs

.. autoclass:: yeelight.Bulb
    :members:
    :undoc-members:

.. autoclass:: yeelight.BulbException
    :members:
    :undoc-members:

.. _flow-objects:

Flow objects
------------

.. autoclass:: yeelight.Flow
    :members:
    :undoc-members:


.. autoclass:: yeelight.HSVTransition
    :members:
    :undoc-members:


.. autoclass:: yeelight.RGBTransition
    :members:
    :undoc-members:


.. autoclass:: yeelight.TemperatureTransition
    :members:
    :undoc-members:


.. autoclass:: yeelight.SleepTransition
    :members:
    :undoc-members:


Transition presets
------------------

.. automodule:: yeelight.transitions
    :members:
    :undoc-members:
    :show-inheritance:


Flow presets
------------

.. automodule:: yeelight.flows
    :members:
    :undoc-members:
    :show-inheritance:


Enums
-----

.. autoclass:: yeelight.BulbType
    :members:
    :undoc-members:


.. autoclass:: yeelight.CronType
    :members:
    :undoc-members:


.. autoclass:: yeelight.LightType
    :members:
    :undoc-members:


.. autoclass:: yeelight.PowerMode
    :members:
    :undoc-members:


.. autoclass:: yeelight.SceneClass
    :members:
    :undoc-members:
